<?php

namespace Drp\NativeEventApp\Test\Support\Fakes;

use Drp\NativeEventApp\Exceptions\InvalidAuthIdentifier;
use PHPUnit\Framework\Assert;

class MagicLinkSigner implements \Drp\NativeEventApp\Contracts\MagicLinkSigner
{
    /** @var string */
    protected $expiry;

    /** @var string */
    protected $signature;

    /** @var bool */
    private $isValid;

    public function __construct(bool $isValid = true)
    {
        $this->isValid = $isValid;
    }

    public function sign(string $authId, string $expiry): string
    {
        return "SIGNATURE_{$authId}_{$expiry}";
    }

    public function verify(string $authIdentifier, string $expiry, string $signature): bool
    {
        $this->expiry = $expiry;
        $this->signature = $signature;

        throw_unless($this->isValid, InvalidAuthIdentifier::hasInvalidSignature());

        return true;
    }

    public function assertVerified(string $expiry, string $signature): void
    {
        Assert::assertEquals($expiry, $this->expiry, 'Expiry was not verified');
        Assert::assertEquals($signature, $this->signature, 'Signature was not verified');
    }
}